summaryrefslogtreecommitdiff
path: root/src/mongo/db/client.h
diff options
context:
space:
mode:
authorSamantha Ritter <samantha.ritter@10gen.com>2016-05-31 14:05:17 -0400
committerJason Carey <jcarey@argv.me>2016-07-12 18:38:37 -0400
commitc263ce1f95586f8652058e6202015a77f9becc49 (patch)
treed623fb9da9fd5da3cc4e20cac0653f1fa4af00eb /src/mongo/db/client.h
parentdead3cf8b4b3cb5528ad1abb9eeb722b395e3632 (diff)
downloadmongo-c263ce1f95586f8652058e6202015a77f9becc49.tar.gz
SERVER-24162 Integrate TransportLayer
Expand the transport layer as needed to replace uses of abstract message port for ingress networking.
Diffstat (limited to 'src/mongo/db/client.h')
-rw-r--r--src/mongo/db/client.h18
1 files changed, 11 insertions, 7 deletions
diff --git a/src/mongo/db/client.h b/src/mongo/db/client.h
index 407a0bac868..a7523981e47 100644
--- a/src/mongo/db/client.h
+++ b/src/mongo/db/client.h
@@ -51,6 +51,10 @@ class AbstractMessagingPort;
class Collection;
class OperationContext;
+namespace transport {
+class Session;
+} // namespace transport
+
typedef long long ConnectionId;
/** the database's concept of an outside "client" */
@@ -59,16 +63,16 @@ public:
/**
* Creates a Client object and stores it in TLS for the current thread.
*
* An unowned pointer to a AbstractMessagingPort may optionally be provided. If 'mp' is
* non-null, then it will be used to augment the thread name, and for reporting purposes.
*
* If provided, 'mp' must outlive the newly-created Client object. Client::destroy() may be used
* to help enforce that the Client does not outlive 'mp'.
*/
- static void initThread(const char* desc, AbstractMessagingPort* mp = 0);
+ static void initThread(const char* desc, transport::Session* session = nullptr);
static void initThread(const char* desc,
ServiceContext* serviceContext,
- AbstractMessagingPort* mp);
+ transport::Session* session);
/**
* Inits a thread if that thread has not already been init'd, setting the thread name to
@@ -159,7 +163,7 @@ public:
private:
friend class ServiceContext;
- Client(std::string desc, ServiceContext* serviceContext, AbstractMessagingPort* p = 0);
+ Client(std::string desc, ServiceContext* serviceContext, transport::Session* session = nullptr);
// Description for the client (e.g. conn8)
@@ -59,16 +63,16 @@ public:
* Creates a Client object and stores it in TLS for the current thread.
*
- * An unowned pointer to a AbstractMessagingPort may optionally be provided. If 'mp' is
- * non-null, then it will be used to augment the thread name, and for reporting purposes.
+ * An unowned pointer to a transport::Session may optionally be provided. If 'session'
+ * is non-null, then it will be used to augment the thread name, and for reporting purposes.
*
@@ -59,16 +63,16 @@ public:
*
- * If provided, 'mp' must outlive the newly-created Client object. Client::destroy() may be used
- * to help enforce that the Client does not outlive 'mp'.
+ * If provided, 'session' must outlive the newly-created Client object. Client::destroy() may
+ * be used to help enforce that the Client does not outlive 'session.'
*/